@@ -98,7 +98,7 @@ class HttpOTA:
             self.logger.info("Skipping check: %s < %s" % (self.format_time(now), self.format_time(next_scheduled_update)))
             status['success'] = True
 
-        self.logger.info(status)
+        self.logger.debug(status)
 
         if status['success']:
             if status['updated']:
